import subprocess


class Struct:
    def __init__(self, **entries): 
            self.__dict__.update(entries)


def get_rpms(koji_client, build_nvr=None, build_id=None):
    if not build_id:
        build_id = koji_client.findBuildID(build_nvr)
    rpms = koji_client.listRPMs(build_id)
    nvrs = []
    rpm_ids = []
    for rpm in rpms:
        nvrs.append('%s.%s' % (rpm['nvr'], rpm['arch']))
        rpm_ids.append(rpm['id'])
    return (nvrs, rpm_ids)

def run_command(command):
    child = subprocess.Popen(command, stdin=subprocess.PIPE,
                             stdout=subprocess.PIPE,
                             stderr=subprocess.PIPE)
    stdout, stderr = child.communicate()
    ret = child.wait()
    return ret, stdout, stderr


class SigulHelper(object):
    def __init__(self, user, passphrase_file, config_file=None):
        self.user = user
        self.passphrase_file = passphrase_file
        self.config_file = config_file

    def build_cmdline(self, *args):
        cmdline = ['sigul', '--batch', '--user-name', self.user,
                   '--passphrase-file', self.passphrase_file]
        if self.config_file:
            cmdline.extend(["--config-file", self.config_file])
        cmdline.extend(args)
        return cmdline

    def build_sign_cmdline(self, key, rpms, koji_instance=None):
        if len(rpms) == 1:
            sigul_cmd = "sign-rpm"
        else:
            sigul_cmd = "sign-rpms"

        command = self.build_cmdline(sigul_cmd, '--store-in-koji',
                                     '--koji-only')
        if koji_instance:
            command.extend(['-k', koji_instance])

        # TODO: See if this always needs to be set or optional
        #if self.v3:
        command.append('--v3-signature')

        command.append(key)

        return command + rpms
